.. This page will be published on the OMFIT modules documentation website:
..          https://omfit.io/modules.html
..
.. The RST markup can be tested here: https://livesphinx.herokuapp.com/
..
.. The module name will be automatically added [DO NOT ADD]
..
.. The contacts for this module will be automatically added [DO NOT ADD]
..
.. The table of contents will be automatically added [DO NOT ADD]

Short Description
-----------------
Run the FOO code

Keywords
--------
Sample, Foo, Documentation, Tutorial

Long Description
----------------
This module prepares the input, runs, and postprocesses the output of the FOO code.

Typical workflows
-----------------
This module is used to:

* write `foo` many times on screen
* translate the output of the BAR module to the ASD module
* generate publication quality figures of `foo`

Supported devices
-----------------
* DIII-D, NSTX, C-Mod

Tutorials
---------
* `YouTube video <http://youtube.com/foo>`_

* `Google docs tutorial <http://docs.google.com/foo>`_

Relevant publications
---------------------
* A. Babel et al. `The art of FOO`, PoP 2018

External resources
------------------
Official webpage: http://foo.com

Technical info
--------------
Set the `foo` variable to True to run faster

.. Extra information will be automatically appended to this page
.. when the online documentation is generated [DO NOT ADD]:
.. * Classes
.. * What are the related modules (super modules using this module, or submodules of this module)
.. * List of contributors for the module [with commit counts]
.. * List of top 10 users
.. * License
